<template>
  <Popup
    ref="pop"
    :title="title"
    width="390px"
    showBtn="true"
    @yes="addData"
    @cancel="close()"
  >
    <el-form ref="form" :model="data" label-width="105px" :rules="rules">
      <el-form-item label="名称:" prop="name">
        <el-select @change="cascaderChange" :value="data.name" allow-create>
          <el-option
            v-for="item in serverList"
            :key="item.value"
            :label="item.label"
            :value="item.value"
          >
          </el-option>
        </el-select>
      </el-form-item>
    </el-form>
  </Popup>
</template>

<script>
import Popup from "@tools/Popup";
import popupTools from "./mixin/popupTools";
import axios from "axios";
export default {
  name: "GetScene",
  components: {
    Popup,
  },
  mixins: [popupTools],
  data() {
    return {
      title: "打开工程",
      data: {
        name: "工程名称",
      },
      rules: {
        name: [{ required: true, message: "请选择图层", trigger: "change" }],
      },
      serverList: [],
      serverURL: "http://192.168.109.128:8080",
      loadServerList: false,
    };
  },
  computed: {},
  mounted() {},
  methods: {
    getServerList() {
      //this.serverURL +
      axios
        .get("../FileManager/fmc/fileList")
        .then((data) => {
          this.serverList = [];
          let servers = data.data;
          servers.forEach((item) => {
            if (item.indexOf(".json") > 0) {
                let filename = item.substring(0, item.indexOf(".json"));
              this.serverList.push({
                label: filename,
                value: filename,
              });
            }
          });
          this.loadServerList = true;
        })
        .catch(() => {
          this.loadServerList = true;
        });
    },
    // 关闭弹窗
    close() {
      // 重置data值
      Object.assign(this.$data, this.$options.data());
      this.$refs.pop.close();
    },
    // 打开弹窗
    open() {
      if (!this.loadServerList) {
        this.getServerList();
      }
      this.$refs.pop.open();
    },
    cascaderChange(item) {
      this.data.name = item;
    },
    // 添加数据
    addData() {
      this.$refs.form.validate((valid) => {
        // 验证通过
        if (valid) {
          this.$emit("success", this.data);

          this.close();
        }
      });
    },
  },
};
</script>

<style scoped lang="less">
.el-form {
  margin-top: 20px;
  margin-right: 10px;
  width: 380px;

  /deep/ .el-form-item__label {
    color: #fff;
    font-size: 18px;
  }
}
</style>
